/*
 * Copyright (C) 2007-2011 Linutop SAS <http://www.linutop.com/>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <glib/gprintf.h>
#include <stdlib.h>

#include "libappstarter/as.h"

#define PLUGIN "flashplayer"

typedef struct _FPlugin {
    gchar *path;
} FPlugin;

FPlugin *plugin;
gchar *cmd = NULL;
gchar *conffile = NULL;

static void
read_config ()
{
    XfceRc *rc;
    rc = as_rc_open(conffile, TRUE);
    if (!rc)
        return;
    xfce_rc_set_group (rc, PLUGIN);
    plugin->path = g_strdup (xfce_rc_read_entry (
        rc, "path", g_getenv ("HOME")));
    xfce_rc_close (rc);
}

static void
write_config ()
{
    XfceRc *rc;
    rc = as_rc_open (conffile, FALSE);
    if (!rc)
        return;
    xfce_rc_set_group (rc, PLUGIN);
    xfce_rc_write_entry (rc, "path", plugin->path);
    xfce_rc_close (rc);
}

/* callbacks */
static void
entry_changed (GtkWidget *fe, gpointer data)
{
    g_free (plugin->path);
    plugin->path = g_strdup (
        as_file_entry_get_filename (AS_FILE_ENTRY (fe)));
    write_config();
}

GtkWidget *
get_config_widget(gchar *file)
{
    GtkWidget *hbox;
    GtkWidget *lbl;
    GtkWidget *fe;

    conffile = g_strdup (file);
    plugin = g_new0 (FPlugin, 1);
    plugin->path = NULL;
    read_config();

    hbox = gtk_hbox_new (FALSE, 2);
    lbl = gtk_label_new (_("Select a file: "));
    gtk_box_pack_start (GTK_BOX (hbox), lbl, FALSE, FALSE, 2);
    gtk_widget_show (lbl);
    fe = as_file_entry_new (_("Select a file"),
                            GTK_FILE_CHOOSER_ACTION_OPEN,
                            plugin->path);
    gtk_box_pack_start (GTK_BOX (hbox), fe, TRUE, TRUE, 2);

    g_signal_connect (G_OBJECT (fe), "changed",
        G_CALLBACK (entry_changed), NULL);

    return hbox;
}

gchar *
get_cmd()
{
    g_free (cmd);
    cmd = g_strconcat ("flashplayer ", plugin->path, NULL);
    return cmd;
}

void
free_all()
{
    g_free (cmd);
    g_free (plugin->path);
    g_free (plugin);
    g_free (conffile);
}
